Name:		navit
Summary:	Car navigation system with routing engine
Version:	0.5.6
Release:	%mkrel 5
Group:		Sciences/Other
License:	GPLv2+
URL:		https://www.navit-project.org/
Source0:	https://github.com/navit-gps/navit/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:	https://www.navit-project.org/maps/osm_bbox_11.3,47.9,11.7,48.2.osm.bz2
Patch1:		navit-0.5.3-speech-dispatcher.patch
Patch2:		navit-0.5.4-Findespeak.cmake.patch
Patch3:		navit-0.5.4-static.patch
Patch4:		navit-0.5.4-sample_map.patch
Patch5:		navit-0.5.6-fix-format-not-a-string-literal.patch
Patch6:		navit-gcc14.patch
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(gtk+-2.0)
BuildRequires:	pkgconfig(fontconfig)
BuildRequires:	pkgconfig(freeglut)
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(fribidi)
BuildRequires:	pkgconfig(libgarmin)
BuildRequires:	pkgconfig(libgeoclue-2.0)
BuildRequires:	pkgconfig(SDL_image)
BuildRequires:	pkgconfig(SDL_ttf)
BuildRequires:	pkgconfig(sdl2)
BuildRequires:	pkgconfig(SDL2_image)
BuildRequires:	pkgconfig(glesv2)
BuildRequires:	pkgconfig(imlib2)
BuildRequires:	pkgconfig(xmu)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(dbus-glib-1)
BuildRequires:	pkgconfig(gdlib)
BuildRequires:	pkgconfig(speech-dispatcher)
BuildRequires:	pkgconfig(libgps) >= 3.23-1
BuildRequires:	pkgconfig(libprotobuf-c)
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5DBus)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Multimedia)
BuildRequires:	pkgconfig(Qt5Positioning)
BuildRequires:	pkgconfig(Qt5Quick)
BuildRequires:	pkgconfig(Qt5Sensors)
BuildRequires:	pkgconfig(Qt5Svg)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	freeimage-devel
BuildRequires:	gettext-devel
BuildRequires:	libespeak-devel
BuildRequires:	nas-devel
BuildRequires:	postgresql-devel
BuildRequires:	cmake
# for P5
BuildRequires:	git-core
BuildRequires:	inkscape
BuildRequires:	rsvg
BuildRequires:	xsltproc
Requires:	fonts-ttf-dejavu
Recommends:	gpsd

%description
Navit is a car navigation system with routing engine. Its modular
design is capable of using vector maps of various formats for routing
and rendering of the displayed map. It's even possible to use multiple
maps at a time.

The GTK+ or SDL user interfaces are designed to work well with touch
screen displays. Points of Interest of various formats are displayed
on the map.

The current vehicle position is either read from gpsd or directly from
NMEA GPS sensors.

The routing engine not only calculates an optimal route to your
destination, but also generates directions and even speaks to you.

%package gtk-gui
Summary:	GTK GUI for Navit navigation system
Group:		Sciences/Other
Requires:	%{name} = %{version}-%{release}

%description gtk-gui
Navit is a car navigation system with routing engine. This package
contains the GTK GUI for Navit. You need to enable this GUI in
/etc/navit/navit.xml or ~/.navit/navit.xml to use it.

%package graphics-sdl
Summary:	SDL graphics renderer for Navit navigation system
Group:		Sciences/Other
Requires:	%{name} = %{version}-%{release}

%description graphics-sdl
Navit is a car navigation system with routing engine. This package
contains the SDL graphics renderer for Navit. You need to enable
this renderer in /etc/navit/navit.xml or ~/.navit/navit.xml to use it.

%prep
%autosetup -p1

install -m 0644 %{SOURCE1} navit/maps

# make sure that include "debug.h" from navit source is used and not
# a system one like <debug.h>
find . -name '*.c' -o -name "*.cpp" | xargs sed -i 's|#include "debug.h"|#include "../debug.h"|'

%build
%define _disable_ld_no_undefined 1

%cmake \
       %ifarch %{ix86} %{arm}
       -DSAMPLE_MAP=FALSE \
       %endif
       -Dgraphics/gd=FALSE \
       -Dbinding/python=FALSE

install -m 0644 %{SOURCE1} %{_vpath_builddir}/navit/maps

%cmake_build

%install
%cmake_install

# Put the config file in /etc: upstream likes it in /usr to be
# relocatable, but that doesn't concern us. The code does check
# in /etc, so we don't need a patch - AdamW 2009/01
mkdir -p %{buildroot}%{_sysconfdir}/%{name}
mv %{buildroot}%{_datadir}/%{name}/%{name}.xml %{buildroot}%{_sysconfdir}/%{name}/%{name}.xml

# Create a README.urpmi - AdamW 2009/01
cat > README.urpmi << EOF
Navit comes with a sample map of Munich, but if you live (or drive!)
anywhere else, you'll need to add another map set. These are not
available as packages because they're rather large and the data changes
on a daily basis, so the packages would have to be refreshed very
often. For instructions on downloading or generating, and installing,
different types of map sets, see these Navit Wiki pages:

http://wiki.navit-project.org/index.php/OpenStreetMaps

http://wiki.navit-project.org/index.php/European_maps

http://wiki.navit-project.org/index.php/Garmin_maps

You should either add the appropriate configuration elements to
/etc/navit/navit.xml, or copy /etc/navit/navit.xml to
~/.navit/navit.xml and edit it there. You may have to remove or comment
out the section for the sample map set, also. Also note that the
default configuration assumes you have a GPS device active, and gpsd
running.
EOF

%find_lang %{name}

%files -f %{name}.lang
%doc AUTHORS CHANGELOG.md README.md README.urpmi
%{_bindir}/*
%{_libdir}/%{name}/
%{_datadir}/dbus-1/services/org.navit_project.navit.service
%exclude %{_libdir}/%{name}/graphics/libgraphics_sdl*
%exclude %{_libdir}/%{name}/gui/libgui_gtk*
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_datadir}/%{name}/
%{_mandir}/man1/*
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.xml

%files gtk-gui
%{_libdir}/%{name}/gui/libgui_gtk*

%files graphics-sdl
%{_libdir}/%{name}/graphics/libgraphics_sdl*


%changelog
* Sun May 18 2025 daviddavid <daviddavid> 0.5.6-5.mga10
+ Revision: 2184639
- rebuild for new gpsd 3.26.1

* Wed Jan 22 2025 daviddavid <daviddavid> 0.5.6-4.mga10
+ Revision: 2140566
- make sure that include "debug.h" from navit source is used and not
  a system one like <debug.h>
- disable also python bindings
- add debian patch to fix build with GCC 14
- disable graphics/gd, gd backend segfaults
- disable long time deprecated gypsy support in favor of libgeoclue2

* Thu Dec 28 2023 daviddavid <daviddavid> 0.5.6-3.mga10
+ Revision: 2023259
- rebuild for py3.12

* Mon Feb 13 2023 daviddavid <daviddavid> 0.5.6-2.mga9
+ Revision: 1941231
- rebuild for new gpsd 3.25

* Sun Nov 20 2022 daviddavid <daviddavid> 0.5.6-1.mga9
+ Revision: 1909178
- new version: 0.5.6
- remove merged upstream patches

* Wed Apr 06 2022 umeabot <umeabot> 0.5.4-8.mga9
+ Revision: 1845882
- Mageia 9 Mass Rebuild

* Tue Mar 01 2022 mrambo3501 <mrambo3501> 0.5.4-7.mga9
+ Revision: 1786835
- rebuild for python-3.10

* Sat Aug 07 2021 tmb <tmb> 0.5.4-6.mga9
+ Revision: 1740088
- rebuild for gpsd 3.23

* Thu Mar 25 2021 daviddavid <daviddavid> 0.5.4-5.mga9
+ Revision: 1710173
- rebuild for python 3.9

* Wed Mar 03 2021 daviddavid <daviddavid> 0.5.4-4.mga9
+ Revision: 1697374
- rebuild for new gpsd 3.22

* Thu Dec 17 2020 umeabot <umeabot> 0.5.4-3.mga8
+ Revision: 1659082
- Rebuild for new Qt5

* Fri Aug 07 2020 daviddavid <daviddavid> 0.5.4-2.mga8
+ Revision: 1611911
- add patch to fix build with Qt 5.15
- add patch to fix build with gpsd 3.21
- use upstream patch to fix build with librsvg >= 2.47
- rebuild for new gpsd 3.21

* Sat Mar 07 2020 daviddavid <daviddavid> 0.5.4-1.mga8
+ Revision: 1554586
- new version: 0.5.4

* Mon Feb 17 2020 daviddavid <daviddavid> 0.5.3-2.mga8
+ Revision: 1537197
- add upstream patch to add compatibility for gpsd 3.20
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Fri Oct 25 2019 daviddavid <daviddavid> 0.5.3-1.mga8
+ Revision: 1455712
- new version: 0.5.3
- switch to cmake build system
- switch to python 3
- update URL and Source URL
- fix speech-dispatcher detection
- enable sdl2 and Qt5 support
- fix sample_map build
- do not build some libraries as shared but as static instead

* Thu Jul 04 2019 daviddavid <daviddavid> 0.2.0-18.mga8
+ Revision: 1418192
- rebuild for new gpsd 3.19

* Tue Oct 09 2018 daviddavid <daviddavid> 0.2.0-17.mga7
+ Revision: 1318859
- add patch to fix compatibility with GPSD API v7
- rebuild for new gpsd 3.18

* Sun Sep 23 2018 umeabot <umeabot> 0.2.0-16.mga7
+ Revision: 1299678
- Mageia 7 Mass Rebuild

* Sun Jul 22 2018 wally <wally> 0.2.0-15.mga7
+ Revision: 1244810
- fix build on aarch64

* Wed Dec 06 2017 daviddavid <daviddavid> 0.2.0-14.mga7
+ Revision: 1181541
- rebuild for new gpsd 3.17

* Tue Sep 05 2017 cjw <cjw> 0.2.0-13.mga7
+ Revision: 1151352
- rebuild for new openssl

* Mon Feb 15 2016 luigiwalser <luigiwalser> 0.2.0-12.mga6
+ Revision: 961712
- add upstream patch to fix build with gpsd 3.11
- rebuild for gpsd
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild
+ tv <tv>
- rebuild for new libgps

* Mon Feb 16 2015 oden <oden> 0.2.0-9.mga5
+ Revision: 815157
- rebuilt for libgd-2.1.1

* Tue Nov 25 2014 cjw <cjw> 0.2.0-8.mga5
+ Revision: 798929
- rebuild against postgresql9.4

* Wed Oct 15 2014 umeabot <umeabot> 0.2.0-7.mga5
+ Revision: 748517
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.2.0-6.mga5
+ Revision: 682809
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Tue May 20 2014 luigiwalser <luigiwalser> 0.2.0-5.mga5
+ Revision: 624021
- fix build with current freetype2
- rebuild for gpsd

* Sat Oct 19 2013 umeabot <umeabot> 0.2.0-4.mga4
+ Revision: 523999
- Mageia 4 Mass Rebuild

* Tue May 28 2013 oden <oden> 0.2.0-3.mga4
+ Revision: 429291
- rebuilt against libgd.so.3
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jan 02 2012 fwang <fwang> 0.2.0-1.mga2
+ Revision: 189672
- new version 0.2.0
- rebuild for new gps

* Fri Sep 23 2011 fwang <fwang> 0.1.1-4.mga2
+ Revision: 146942
- only glu is enough

* Thu Sep 22 2011 fwang <fwang> 0.1.1-3.mga2
+ Revision: 146666
- bump rel
- drop .la files

* Wed Apr 06 2011 tv <tv> 0.1.1-2.mga1
+ Revision: 81040
- imported package navit


* Wed Nov 03 2010 Michael Scherer <misc@mandriva.org> 0.1.1-2mdv2011.0
+ Revision: 592728
- rebuild for python 2.7

* Tue Jan 19 2010 Emmanuel Andry <eandry@mandriva.org> 0.1.1-1mdv2010.1
+ Revision: 493927
- New version 0.1.1
- drop p1 (useless), p2 p3 p4 (merged upstream)
- add patch to fix build with gpsd
- CEGUI is not used anymore, dropping subpackage
- disable QT4 gui, missing qpainter headers
- add gtk-gui subpackage

* Fri Nov 20 2009 Michael Scherer <misc@mandriva.org> 0.1.0-3mdv2010.1
+ Revision: 467637
- fix BuildRequires
- rebuilt

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild

* Tue Jan 06 2009 Adam Williamson <awilliamson@mandriva.org> 0.1.0-1mdv2009.1
+ Revision: 326445
- ok, it wasn't the library names, i was just missing the qt4 br...
- fix lib names on x86-64 in file list
- import navit


